Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS SSO.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for AWS SSO - AWS Identity and Access Management

# Actions, resources, and condition keys for AWS SSO

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssso.html .

AWS SSO (service prefix: `sso` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS SSO
- Resource types defined by AWS SSO
- Condition keys for AWS SSO

## Actions defined by AWS SSO

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateDirectory | Connect a directory to be used by AWS Single Sign-On | Write |  |  |
AssociateProfile | Create an association between a directory user or group and a profile | Write |  |  |
AttachManagedPolicyToPermissionSet | Attaches an AWS managed policy to a permission set. | Write | Instance* |  |
PermissionSet* |  |
CreateAccountAssignment | Assigns access to a Principal for a specified AWS account using a specified permission set. | Write | Account* |  |
Instance* |  |
PermissionSet* |  |
CreateApplicationInstance | Add an application instance to AWS Single Sign-On | Write |  |  |
CreateApplicationInstanceCertificate | Add a new certificate for an application instance | Write |  |  |
CreateManagedApplicationInstance | Add a managed application instance to AWS Single Sign-On | Write |  |  |
CreatePermissionSet | Create a permission set | Write | Instance* |  |
CreateProfile | Create a profile for an application instance | Write |  |  |
CreateTrust | Create a federation trust in a target account | Write |  |  |
DeleteAccountAssignment | Deletes a Principal's access from a specified AWS account using a specified permission set. | Write | Account* |  |
Instance* |  |
PermissionSet* |  |
DeleteApplicationInstance | Delete the application instance | Write |  |  |
DeleteApplicationInstanceCertificate | Delete an inactive or expired certificate from the application instance | Write |  |  |
DeleteInlinePolicyFromPermissionSet | Deletes the inline policy from a specified permission set. | Write | Instance* |  |
PermissionSet* |  |
DeleteManagedApplicationInstance | Delete the managed application instance | Write |  |  |
DeletePermissionSet | Delete a permission set | Write | Instance* |  |
PermissionSet* |  |
DeletePermissionsPolicy | Delete the permission policy associated with a permission set | Write |  |  |
DeleteProfile | Delete the profile for an application instance | Write |  |  |
DescribeAccountAssignmentCreationStatus | Describes the status of the assignment creation request. | Read | Instance* |  |
DescribeAccountAssignmentDeletionStatus | Describes the status of an assignment deletion request. | Read | Instance* |  |
DescribePermissionSet | Describes a permission set | Read | Instance* |  |
PermissionSet* |  |
DescribePermissionSetProvisioningStatus | Describes the status for the given Permission Set Provisioning request. | Read | Instance* |  |
DescribePermissionsPolicies | Retrieve all the permissions policies associated with a permission set | Read |  |  |
DescribeRegisteredRegions | Obtains the regions where your organization has enabled AWS Single Sign-on | Read |  |  |
DetachManagedPolicyFromPermissionSet | Detaches the attached AWS managed policy from the specified permission set. | Write | Instance* |  |
PermissionSet* |  |
DisassociateDirectory | Disassociate a directory to be used by AWS Single Sign-On | Write |  |  |
DisassociateProfile | Disassociate a directory user or group from a profile | Write |  |  |
GetApplicationInstance | Retrieve details for an application instance | Read |  |  |
GetApplicationTemplate | Retrieve application template details | Read |  |  |
GetInlinePolicyForPermissionSet | Obtains the inline policy assigned to the permission set. | Read | Instance* |  |
PermissionSet* |  |
GetManagedApplicationInstance | Retrieve details for an application instance | Read |  |  |
GetMfaDeviceManagementForDirectory | Retrieve Mfa Device Management settings for the directory | Read |  |  |
GetPermissionSet | Retrieve details of a permission set | Read |  |  |
GetPermissionsPolicy | Retrieve all permission policies associated with a permission set | Read |  |  | sso:DescribePermissionsPolicies
GetProfile | Retrieve a profile for an application instance | Read |  |  |
GetSSOStatus | Check if AWS Single Sign-On is enabled | Read |  |  |
GetSharedSsoConfiguration | Retrieve shared configuration for the current SSO instance | Read |  |  |
GetSsoConfiguration | Retrieve configuration for the current SSO instance | Read |  |  |
GetTrust | Retrieve the federation trust in a target account | Read |  |  |
ImportApplicationInstanceServiceProviderMetadata | Update the application instance by uploading an application SAML metadata file provided by the service provider | Write |  |  |
ListAccountAssignmentCreationStatus | Lists the status of the AWS account assignment creation requests for a specified SSO instance. | List | Instance* |  |
ListAccountAssignmentDeletionStatus | Lists the status of the AWS account assignment deletion requests for a specified SSO instance. | List | Instance* |  |
ListAccountAssignments | Lists the assignee of the specified AWS account with the specified permission set. | List | Account* |  |
Instance* |  |
PermissionSet* |  |
ListAccountsForProvisionedPermissionSet | Lists all the AWS accounts where the specified permission set is provisioned. | List | Instance* |  |
PermissionSet* |  |
ListApplicationInstanceCertificates | Retrieve all of the certificates for a given application instance | List |  |  |
ListApplicationInstances | Retrieve all application instances | List |  |  | sso:GetApplicationInstance
ListApplicationTemplates | Retrieve all supported application templates | List |  |  | sso:GetApplicationTemplate
ListApplications | Retrieve all supported applications | List |  |  |
ListDirectoryAssociations | Retrieve details about the directory connected to AWS Single Sign-On | List |  |  |
ListInstances | Lists the SSO Instances that the caller has access to. | List |  |  |
ListManagedPoliciesInPermissionSet | Lists the AWS managed policies that are attached to a specified permission set. | List | Instance* |  |
PermissionSet* |  |
ListPermissionSetProvisioningStatus | Lists the status of the Permission Set Provisioning requests for a specified SSO instance. | List | Instance* |  |
ListPermissionSets | Retrieve all permission sets | List | Instance* |  |
ListPermissionSetsProvisionedToAccount | Lists all the permission sets that are provisioned to a specified AWS account. | List | Account* |  |
Instance* |  |
ListProfileAssociations | Retrieve the directory user or group associated with the profile | List |  |  |
ListProfiles | Retrieve all profiles for an application instance | List |  |  | sso:GetProfile
ListTagsForResource | Lists the tags that are attached to a specified resource. | List | Instance* |  |
PermissionSet* |  |
ProvisionPermissionSet | The process by which a specified permission set is provisioned to the specified target. | Write | Account* |  |
Instance* |  |
PermissionSet* |  |
PutInlinePolicyToPermissionSet | Attaches an IAM inline policy to a permission set. | Write | Instance* |  |
PermissionSet* |  |
PutMfaDeviceManagementForDirectory | Put Mfa Device Management settings for the directory | Write |  |  |
PutPermissionsPolicy | Add a policy to a permission set | Write |  |  |
StartSSO | Initialize AWS Single Sign-On | Write |  |  |
TagResource | Associates a set of tags with a specified resource. | Tagging | Instance* |  |
PermissionSet* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Disassociates a set of tags from a specified resource. | Tagging | Instance* |  |
PermissionSet* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateApplicationInstanceActiveCertificate | Set a certificate as the active one for this application instance | Write |  |  |
UpdateApplicationInstanceDisplayData | Update display data of an application instance | Write |  |  |
UpdateApplicationInstanceResponseConfiguration | Update federation response configuration for the application instance | Write |  |  |
UpdateApplicationInstanceResponseSchemaConfiguration | Update federation response schema configuration for the application instance | Write |  |  |
UpdateApplicationInstanceSecurityConfiguration | Update security details for the application instance | Write |  |  |
UpdateApplicationInstanceServiceProviderConfiguration | Update service provider related configuration for the application instance | Write |  |  |
UpdateApplicationInstanceStatus | Update the status of an application instance | Write |  |  |
UpdateDirectoryAssociation | Update the user attribute mappings for your connected directory | Write |  |  |
UpdateManagedApplicationInstanceStatus | Update the status of a managed application instance | Write |  |  |
UpdatePermissionSet | Update the permission set. | Write | Instance* |  |
PermissionSet* |  |
UpdateProfile | Update the profile for an application instance | Write |  |  |
UpdateSSOConfiguration | Update the configuration for the current SSO instance | Write |  |  |
UpdateTrust | Update the federation trust in a target account | Write |  |  |

## Resource types defined by AWS SSO

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
PermissionSet | `arn:$ { Partition}:sso:::permissionSet/$ { InstanceId}/$ { PermissionSetId}` | aws:ResourceTag/${TagKey}
Account | `arn:$ { Partition}:sso:::account/$ { AccountId}` |
Instance | `arn:$ { Partition}:sso:::instance/$ { InstanceId}` |

## Condition keys for AWS SSO

AWS SSO defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} |  | String
aws:ResourceTag/${TagKey} |  | String
aws:TagKeys |  | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.